@@ -25,7 +25,7 @@ has baz => (
 );
 
 has bo => (
-    is  => 'wo',
+    is  => 'once',
     isa => HashRef,
 );
 
